const TOGGLE_COMPLETED = 'toggle completed';
const DELETE_TASK = 'delete a task';

const createToggleCompleted = (id) => ({
	type: TOGGLE_COMPLETED,
	id: id
});

const createDeleteTask = (id) => ({
	type: DELETE_TASK,
	id: id
});

const toggleTaskAsCompleted = (task) => (
	{...task, completed: !task.completed });

const reminders = (tasks, action) => {
	switch(action.type) {
		case TOGGLE_COMPLETED:
		  return tasks.map(
				task => task.id === action.id ? toggleTaskAsCompleted(task) : task);

		case DELETE_TASK:
		  return tasks.filter(task => task.id !== action.id);

		default:
		  return tasks;
	}
};

const createAStore = function() {
  const tasksFromLocalStorage = localStorage.getItem('tasks');
  
  if(!tasksFromLocalStorage) {
    const initialState = [
     {id: 1, name: 'task 1', completed: false},
     {id: 2, name: 'task 2', completed: false},
     {id: 3, name: 'task 3', completed: false},
     {id: 4, name: 'task 4', completed: false},
     {id: 5, name: 'task 5', completed: false},
     {id: 6, name: 'task 6', completed: false},
    ];  
    
    localStorage.setItem('tasks', JSON.stringify(initialState));
  }
  

  const restoredTasks = JSON.parse(localStorage.getItem('tasks'));
  
  const store = Redux.createStore(reminders, restoredTasks);
  
  store.subscribe(() => 
    localStorage.setItem('tasks', JSON.stringify(store.getState())));
  
  return store;
}
                
const store = createAStore();

store.subscribe(() => displayTasks());

const displayTasks = function() {                      
  const tasks = store.getState();
  
  const htmlTasks = tasks.map(task => 
     `<p>
        ${task.name}---${task.completed}
        <button onclick="toggle(${task.id})">toggle</button>
        <button onclick="deleteTask(${task.id})">delete</button>
      </p>
     `).join('')
  
  document.getElementById('display').innerHTML = htmlTasks;
}

const toggle = function(id) {
  store.dispatch(createToggleCompleted(id));
}

const deleteTask = function(id) {
  store.dispatch(createDeleteTask(id));
}